# 020

|                                                | Asko induction hob 2   |
|:-----------------------------------------------|:-----------------------|
| bindTime                                       | 1629723678408          |
| createTime                                     | 0                      |
| deviceFeatureCode                              | 63c45b513e1a4bf7       |
| deviceFeatureName                              | HOB                    |
| deviceId                                       | <redacted>             |
| deviceNickName                                 | Atag hob               |
| deviceTypeCode                                 | 020                    |
| deviceTypeName                                 |                        |
| offlineState                                   | 1                      |
| puid                                           | <redacted>             |
| role                                           | 1                      |
| roomId                                         | 142500                 |
| roomName                                       | AR kitchen             |
| seq                                            | 0                      |
| statusList.Alarm_Hob_Hood_Started              | 0                      |
| statusList.Alarm_NTC_TC                        | 0                      |
| statusList.Alarm_NTC_coil_overheating          | 0                      |
| statusList.Alarm_NTC_power                     | 0                      |
| statusList.Alarm_auto_program_notification     | 0                      |
| statusList.Alarm_automatic_switch_off_zone     | 0                      |
| statusList.Alarm_timer_ended                   | 0                      |
| statusList.Alarm_voltage                       | 0                      |
| statusList.Alarm_zone_turned_off               | 0                      |
| statusList.Child_lock                          | 8131                   |
| statusList.Device_status                       | 8018                   |
| statusList.ECO_mode                            | 8202                   |
| statusList.SL                                  | 6                      |
| statusList.SL1_Active_timer                    | 0                      |
| statusList.SL1_Alarm_NTC_coil_overheating      | 0                      |
| statusList.SL1_Alarm_auto_program_notification | 0                      |
| statusList.SL1_Alarm_automatic_switch_off_zone | 0                      |
| statusList.SL1_Alarm_timer_ended               | 0                      |
| statusList.SL1_Alarm_zone_turned_off           | 0                      |
| statusList.SL1_Bridge_function_active          | 0                      |
| statusList.SL1_Functions                       | 8166                   |
| statusList.SL1_NTC_sensor                      | 0                      |
| statusList.SL1_Pot_detected                    | 8127                   |
| statusList.SL1_Power_level                     | 0                      |
| statusList.SL1_Power_level_max                 | 13                     |
| statusList.SL1_Status                          | 0                      |
| statusList.SL1_Zone_shape                      | 8344                   |
| statusList.SL2_Active_timer                    | 0                      |
| statusList.SL2_Alarm_NTC_coil_overheating      | 0                      |
| statusList.SL2_Alarm_auto_program_notification | 0                      |
| statusList.SL2_Alarm_automatic_switch_off_zone | 0                      |
| statusList.SL2_Alarm_timer_ended               | 0                      |
| statusList.SL2_Alarm_zone_turned_off           | 0                      |
| statusList.SL2_Bridge_function_active          | 0                      |
| statusList.SL2_Functions                       | 8166                   |
| statusList.SL2_NTC_sensor                      | 0                      |
| statusList.SL2_Pot_detected                    | 8127                   |
| statusList.SL2_Power_level                     | 0                      |
| statusList.SL2_Power_level_max                 | 13                     |
| statusList.SL2_Status                          | 0                      |
| statusList.SL2_Zone_shape                      | 8344                   |
| statusList.SL3_Active_timer                    | 0                      |
| statusList.SL3_Alarm_NTC_coil_overheating      | 0                      |
| statusList.SL3_Alarm_auto_program_notification | 0                      |
| statusList.SL3_Alarm_automatic_switch_off_zone | 0                      |
| statusList.SL3_Alarm_timer_ended               | 0                      |
| statusList.SL3_Alarm_zone_turned_off           | 0                      |
| statusList.SL3_Bridge_function_active          | 0                      |
| statusList.SL3_Functions                       | 8166                   |
| statusList.SL3_NTC_sensor                      | 0                      |
| statusList.SL3_Pot_detected                    | 8127                   |
| statusList.SL3_Power_level                     | 0                      |
| statusList.SL3_Power_level_max                 | 13                     |
| statusList.SL3_Status                          | 0                      |
| statusList.SL3_Zone_shape                      | 8341                   |
| statusList.SL4_Active_timer                    | 0                      |
| statusList.SL4_Alarm_NTC_coil_overheating      | 0                      |
| statusList.SL4_Alarm_auto_program_notification | 0                      |
| statusList.SL4_Alarm_automatic_switch_off_zone | 0                      |
| statusList.SL4_Alarm_timer_ended               | 0                      |
| statusList.SL4_Alarm_zone_turned_off           | 0                      |
| statusList.SL4_Bridge_function_active          | 0                      |
| statusList.SL4_Functions                       | 8166                   |
| statusList.SL4_NTC_sensor                      | 0                      |
| statusList.SL4_Pot_detected                    | 8127                   |
| statusList.SL4_Power_level                     | 0                      |
| statusList.SL4_Power_level_max                 | 13                     |
| statusList.SL4_Status                          | 0                      |
| statusList.SL4_Zone_shape                      | 8344                   |
| statusList.SL5_Active_timer                    | 0                      |
| statusList.SL5_Alarm_NTC_coil_overheating      | 0                      |
| statusList.SL5_Alarm_auto_program_notification | 0                      |
| statusList.SL5_Alarm_automatic_switch_off_zone | 0                      |
| statusList.SL5_Alarm_timer_ended               | 0                      |
| statusList.SL5_Alarm_zone_turned_off           | 0                      |
| statusList.SL5_Bridge_function_active          | 0                      |
| statusList.SL5_Functions                       | 8166                   |
| statusList.SL5_NTC_sensor                      | 0                      |
| statusList.SL5_Pot_detected                    | 8127                   |
| statusList.SL5_Power_level                     | 0                      |
| statusList.SL5_Power_level_max                 | 13                     |
| statusList.SL5_Status                          | 0                      |
| statusList.SL5_Zone_shape                      | 8344                   |
| statusList.SL6_Active_timer                    | 0                      |
| statusList.SL6_Alarm_NTC_coil_overheating      | 0                      |
| statusList.SL6_Alarm_auto_program_notification | 0                      |
| statusList.SL6_Alarm_automatic_switch_off_zone | 0                      |
| statusList.SL6_Alarm_timer_ended               | 0                      |
| statusList.SL6_Alarm_zone_turned_off           | 0                      |
| statusList.SL6_Bridge_function_active          | 0                      |
| statusList.SL6_Functions                       | 8166                   |
| statusList.SL6_NTC_sensor                      | 0                      |
| statusList.SL6_Pot_detected                    | 8127                   |
| statusList.SL6_Power_level                     | 0                      |
| statusList.SL6_Power_level_max                 | 13                     |
| statusList.SL6_Status                          | 0                      |
| statusList.SL6_Zone_shape                      | 8345                   |
| statusList.Total_time_of_cooking_in_hours      | 491                    |
| statusList.Zone_number                         | 5                      |
| statusList.daily_energy_kwh                    | 0                      |
| useTime                                        | 0                      |
| wifiId                                         | <redacted>             |

## Generated from

- [`Asko_induction_hob_2.json`](Asko_induction_hob_2.json)
